Struct RingBuffer

pub struct RingBuffer { /* private fields */ }
Single producer, many consumer (SPMC) ring buffer backed by shared memory.

Implementations

Source

impl RingBuffer

pub fn new(bytes: &[u8]) -> Self

Create new RingBuffer by wrapping provided bytes. It is necessary to call into_writer() or into_reader() following the buffer construction to start using it.

pub fn into_writer(self) -> Writer

Will consume self and return instance of writer backed by this ring buffer.

pub fn into_writer_with_metadata<F: FnOnce(&mut [u8])>( self, metadata: F, ) -> Writer

Will consume self and return instance of writer backed by this ring buffer. This method also accepts closure to populate metadata buffer.

pub fn into_reader(self) -> Reader

Will consume self and return instance of reader backed by this ring buffer. The reader position will be set to producer most up-to-date position.