Struct Writer

pub struct Writer { /* private fields */ }
Wraps RingBuffer and allows to publish messages. Only single writer should be present at any time.

Implementations

Source

impl Writer

pub fn claim(&self, len: usize, fin: bool) -> Claim<'_>

Claim part of the underlying RingBuffer for publication. The fin flag is used to indicate final message fragment.

Panics

When aligned message length is greater than the MTU.

pub fn claim_with_user_defined( &self, len: usize, fin: bool, user_defined: u32, ) -> Claim<'_>

Claim part of the underlying RingBuffer for publication. The fin flag is used to indicate final message fragment. This method also accepts user_defined value that will be attached to the message frame header.

Panics

When aligned message length is greater than the MTU.

pub fn continuation(&self, len: usize, fin: bool) -> Claim<'_>

Claim part of the underlying RingBuffer for continuation frame publication also passing fin value to indicate final message fragment.

Panics

When aligned message length is greater than the MTU.

pub fn heartbeat(&self) -> Claim<'_>

Claim part of the underlying RingBuffer for heartbeat frame publication (zero payload, no user defined field and no fragmentation). This operation will always succeed.

pub fn heartbeat_with_user_defined(&self, user_defined: u32) -> Claim<'_>

Claim part of the underlying RingBuffer for heartbeat frame publication with user defined field (zero payload and no fragmentation). This operation will always succeed.

pub const fn mtu(&self) -> usize

Get maximum permissible unaligned payload length that can be accepted by the buffer. It is calculated as min(capacity / 2 - size_of::<FrameHeader>(), MAX_PAYLOAD_LEN) where MAX_PAYLOAD_LEN is (1 << 31) - 1.